# GroqFlow 🚀

GroqFlow™ is the easiest way to get started with Groq's technology. GroqFlow provides an automated workflow for compiling Machine Learning, Artifical Intelligence, and High-Performance Computing workloads into Groq programs and executing those programs on the Groq Language Processing Unit™ (LPU).

---

## System Requirements

To begin, we recommend that your system meets the following software and hardware requirements:

- Ubuntu 22.04 or Rocky 8.4 Linux distribution.
- 32GB RAM (or more) to build models.
- 8 LPUs (especially for larger models) to run models.
- GroqWare Suite™ version >=0.9.2.1 installation*:
  - Groq Developer Tools Package (groq-devtools) for building and compiling models.
  - Groq Runtime Package (groq-runtime) for running compiled models on Groq hardware.

*For information on how to install GroqWare Suite on your system, create an account on our [portal](https://support.groq.com/) and view the [GroqWare Quick Start Guide](https://support.groq.com/#/downloads/view/groqware-qsg) for installation instructions.

---

## Navigating GroqFlow

* [Documentation](docs/): All GroqFlow documentation, including the installation guide, user guide, known issues, and versioning.

* [Examples](examples/): Includes various GroqFlow examples.

* [GroqFlow](groqflow/): The source code for the `groqflow` package.

* [Proof Points](proof_points/): Machine learning proof points using GroqFlow.

* [README.md](readme.md): This README.

---

## Contributors

GroqFlow development is primarily conducted within Groq's internal repo and is periodically synced to GitHub. This approach means that developer contributions are not immediately obvious in the commit log.

This project follows the [all-contributors](https://allcontributors.org) specification.
Contributions of any kind are welcome!
